==> tool-sql-1.1.10-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/SimpleAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleFormalizerSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleParticipantSet;
import io.ciera.tool.sql.ooaofooa.association.SimpleAssociation;
import io.ciera.tool.sql.ooaofooa.association.SimpleAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleFormalizerSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleParticipantSetImpl;

import java.util.Arrays;
import java.util.List;


public class SimpleAssociationSetImpl extends InstanceSet<SimpleAssociationSet,SimpleAssociation> implements SimpleAssociationSet {

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( SimpleAssociation simpleassociation : this ) simpleassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( SimpleAssociation simpleassociation : this ) associationset.add( simpleassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsSimpleParticipantSet R207_relates_ClassAsSimpleParticipant() throws XtumlException {
        ClassAsSimpleParticipantSet classassimpleparticipantset = new ClassAsSimpleParticipantSetImpl();
        for ( SimpleAssociation simpleassociation : this ) classassimpleparticipantset.addAll( simpleassociation.R207_relates_ClassAsSimpleParticipant() );
        return classassimpleparticipantset;
    }
    @Override
    public ClassAsSimpleFormalizerSet R208_relates_ClassAsSimpleFormalizer() throws XtumlException {
        ClassAsSimpleFormalizerSet classassimpleformalizerset = new ClassAsSimpleFormalizerSetImpl();
        for ( SimpleAssociation simpleassociation : this ) classassimpleformalizerset.add( simpleassociation.R208_relates_ClassAsSimpleFormalizer() );
        return classassimpleformalizerset;
    }


    @Override
    public SimpleAssociation nullElement() {
        return SimpleAssociationImpl.EMPTY_SIMPLEASSOCIATION;
    }

    @Override
    public SimpleAssociationSet emptySet() {
      return new SimpleAssociationSetImpl();
    }

    @Override
    public SimpleAssociationSet value() {
        return this;
    }

    @Override
    public List<SimpleAssociation> elements() {
        return Arrays.asList(toArray(new SimpleAssociation[0]));
    }

}

==> tool-sql-2.2.0-sources.jar: io/ciera/tool/sql/ooaofooa/association/impl/SimpleAssociationSetImpl.java <==
package io.ciera.tool.sql.ooaofooa.association.impl;


import io.ciera.runtime.summit.classes.InstanceSet;
import io.ciera.runtime.summit.exceptions.XtumlException;
import io.ciera.runtime.summit.types.UniqueId;
import io.ciera.tool.sql.ooaofooa.association.AssociationSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleFormalizerSet;
import io.ciera.tool.sql.ooaofooa.association.ClassAsSimpleParticipantSet;
import io.ciera.tool.sql.ooaofooa.association.SimpleAssociation;
import io.ciera.tool.sql.ooaofooa.association.SimpleAssociationSet;
import io.ciera.tool.sql.ooaofooa.association.impl.AssociationSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleFormalizerSetImpl;
import io.ciera.tool.sql.ooaofooa.association.impl.ClassAsSimpleParticipantSetImpl;

import java.util.Arrays;
import java.util.Comparator;
import java.util.List;


public class SimpleAssociationSetImpl extends InstanceSet<SimpleAssociationSet,SimpleAssociation> implements SimpleAssociationSet {

    public SimpleAssociationSetImpl() {
    }

    public SimpleAssociationSetImpl(Comparator<? super SimpleAssociation> comp) {
        super(comp);
    }

    // attributes
    @Override
    public void setRel_ID( UniqueId ref_Rel_ID ) throws XtumlException {
        for ( SimpleAssociation simpleassociation : this ) simpleassociation.setRel_ID( ref_Rel_ID );
    }


    // selections
    @Override
    public AssociationSet R206_is_a_Association() throws XtumlException {
        AssociationSet associationset = new AssociationSetImpl();
        for ( SimpleAssociation simpleassociation : this ) associationset.add( simpleassociation.R206_is_a_Association() );
        return associationset;
    }
    @Override
    public ClassAsSimpleParticipantSet R207_relates_ClassAsSimpleParticipant() throws XtumlException {
        ClassAsSimpleParticipantSet classassimpleparticipantset = new ClassAsSimpleParticipantSetImpl();
        for ( SimpleAssociation simpleassociation : this ) classassimpleparticipantset.addAll( simpleassociation.R207_relates_ClassAsSimpleParticipant() );
        return classassimpleparticipantset;
    }
    @Override
    public ClassAsSimpleFormalizerSet R208_relates_ClassAsSimpleFormalizer() throws XtumlException {
        ClassAsSimpleFormalizerSet classassimpleformalizerset = new ClassAsSimpleFormalizerSetImpl();
        for ( SimpleAssociation simpleassociation : this ) classassimpleformalizerset.add( simpleassociation.R208_relates_ClassAsSimpleFormalizer() );
        return classassimpleformalizerset;
    }


    @Override
    public SimpleAssociation nullElement() {
        return SimpleAssociationImpl.EMPTY_SIMPLEASSOCIATION;
    }

    @Override
    public SimpleAssociationSet emptySet() {
      return new SimpleAssociationSetImpl();
    }

    @Override
    public SimpleAssociationSet emptySet(Comparator<? super SimpleAssociation> comp) {
      return new SimpleAssociationSetImpl(comp);
    }

    @Override
    public SimpleAssociationSet value() {
        return this;
    }

    @Override
    public List<SimpleAssociation> elements() {
        return Arrays.asList(toArray(new SimpleAssociation[0]));
    }

}
